@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019,2020 Nicola Di Lieto <nicola.dilieto@gmail.com>
+ * Copyright (C) 2019-2021 Nicola Di Lieto <nicola.dilieto@gmail.com>
  *
  * This file is part of uacme.
  *
@@ -21,8 +21,17 @@
 #ifndef __MSG_H__
 #define __MSG_H__
 
+#include <stddef.h>
+
 extern int g_loglevel;
 
+#ifdef __GNUC__
+void __attribute__((format (printf, 2, 3))) msg(int level,
+        const char *format, ...);
+#else
 void msg(int level, const char *format, ...);
+#endif
+
+void msg_hd(int level, const char *prefix, const void *data, size_t len);
 
 #endif
